@@ -101,6 +101,26 @@ SEXP R_H5Fflush(SEXP R_object_id, SEXP R_scope){
   return(__ret_list);
 }
 
+/* H5_DLL herr_t H5Fformat_convert(hid_t fid); */
+SEXP R_H5Fformat_convert(SEXP R_fid){
+  int vars_protected=0;
+  hid_t fid = SEXP_to_longlong(R_fid, 0);
+  herr_t return_val = H5Fformat_convert(fid);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL hid_t H5Fget_access_plist(hid_t file_id); */
 SEXP R_H5Fget_access_plist(SEXP R_file_id){
   int vars_protected=0;
@@ -213,6 +233,40 @@ SEXP R_H5Fget_filesize(SEXP R_file_id, SEXP R_size){
   return(__ret_list);
 }
 
+/* H5_DLL ssize_t H5Fget_free_sections(hid_t file_id, H5F_mem_t type, size_t nsects, H5F_sect_info_t *sect_info); */
+SEXP R_H5Fget_free_sections(SEXP R_file_id, SEXP R_type, SEXP R_nsects, SEXP R_sect_info){
+  hsize_t size_helper;
+  SEXP R_helper = R_NilValue;
+  int vars_protected=0;
+  R_sect_info = PROTECT(duplicate(R_sect_info));
+  vars_protected++;
+  hid_t file_id = SEXP_to_longlong(R_file_id, 0);
+  H5F_mem_t type = SEXP_to_longlong(R_type, 0);
+  size_t nsects = SEXP_to_longlong(R_nsects, 0);
+  R_helper = PROTECT(RToH5(R_sect_info, h5_datatype[DT_H5F_sect_info_t], guess_nelem(R_sect_info, h5_datatype[DT_H5F_sect_info_t])));
+  H5F_sect_info_t* sect_info= (H5F_sect_info_t*) VOIDPTR(R_helper);
+  vars_protected++;
+  ssize_t return_val = H5Fget_free_sections(file_id, type, nsects, sect_info);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  size_helper = guess_nelem(R_sect_info, h5_datatype[DT_H5F_sect_info_t]);
+  R_sect_info = PROTECT(H5ToR_single_step(sect_info, h5_datatype[DT_H5F_sect_info_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 2));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SET_VECTOR_ELT(__ret_list, 1, R_sect_info);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_STRING_ELT(__ret_list_names, 1, mkChar("sect_info"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL hssize_t H5Fget_freespace(hid_t file_id); */
 SEXP R_H5Fget_freespace(SEXP R_file_id){
   int vars_protected=0;
@@ -233,32 +287,64 @@ SEXP R_H5Fget_freespace(SEXP R_file_id){
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Fget_info(hid_t obj_id, H5F_info_t *bh_info); */
-SEXP R_H5Fget_info(SEXP R_obj_id, SEXP R_bh_info){
+/* H5_DLL herr_t H5Fget_info1(hid_t obj_id, H5F_info1_t *finfo); */
+SEXP R_H5Fget_info1(SEXP R_obj_id, SEXP R_finfo){
   hsize_t size_helper;
   SEXP R_helper = R_NilValue;
   int vars_protected=0;
-  R_bh_info = PROTECT(duplicate(R_bh_info));
+  R_finfo = PROTECT(duplicate(R_finfo));
   vars_protected++;
   hid_t obj_id = SEXP_to_longlong(R_obj_id, 0);
-  R_helper = PROTECT(RToH5(R_bh_info, h5_datatype[DT_H5F_info_t], guess_nelem(R_bh_info, h5_datatype[DT_H5F_info_t])));
-  H5F_info_t* bh_info= (H5F_info_t*) VOIDPTR(R_helper);
+  R_helper = PROTECT(RToH5(R_finfo, h5_datatype[DT_H5F_info1_t], guess_nelem(R_finfo, h5_datatype[DT_H5F_info1_t])));
+  H5F_info1_t* finfo= (H5F_info1_t*) VOIDPTR(R_helper);
   vars_protected++;
-  herr_t return_val = H5Fget_info(obj_id, bh_info);
+  herr_t return_val = H5Fget_info1(obj_id, finfo);
   SEXP R_return_val= R_NilValue;
   R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
   vars_protected++;
-  size_helper = guess_nelem(R_bh_info, h5_datatype[DT_H5F_info_t]);
-  R_bh_info = PROTECT(H5ToR_single_step(bh_info, h5_datatype[DT_H5F_info_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  size_helper = guess_nelem(R_finfo, h5_datatype[DT_H5F_info1_t]);
+  R_finfo = PROTECT(H5ToR_single_step(finfo, h5_datatype[DT_H5F_info1_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
   vars_protected++;
   SEXP __ret_list;
   PROTECT(__ret_list = allocVector(VECSXP, 2));
   SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SET_VECTOR_ELT(__ret_list, 1, R_bh_info);
+  SET_VECTOR_ELT(__ret_list, 1, R_finfo);
   SEXP __ret_list_names;
   PROTECT(__ret_list_names = allocVector(STRSXP, 2));
   SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_STRING_ELT(__ret_list_names, 1, mkChar("bh_info"));
+  SET_STRING_ELT(__ret_list_names, 1, mkChar("finfo"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
+/* H5_DLL herr_t H5Fget_info2(hid_t obj_id, H5F_info2_t *finfo); */
+SEXP R_H5Fget_info2(SEXP R_obj_id, SEXP R_finfo){
+  hsize_t size_helper;
+  SEXP R_helper = R_NilValue;
+  int vars_protected=0;
+  R_finfo = PROTECT(duplicate(R_finfo));
+  vars_protected++;
+  hid_t obj_id = SEXP_to_longlong(R_obj_id, 0);
+  R_helper = PROTECT(RToH5(R_finfo, h5_datatype[DT_H5F_info2_t], guess_nelem(R_finfo, h5_datatype[DT_H5F_info2_t])));
+  H5F_info2_t* finfo= (H5F_info2_t*) VOIDPTR(R_helper);
+  vars_protected++;
+  herr_t return_val = H5Fget_info2(obj_id, finfo);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  size_helper = guess_nelem(R_finfo, h5_datatype[DT_H5F_info2_t]);
+  R_finfo = PROTECT(H5ToR_single_step(finfo, h5_datatype[DT_H5F_info2_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 2));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SET_VECTOR_ELT(__ret_list, 1, R_finfo);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_STRING_ELT(__ret_list_names, 1, mkChar("finfo"));
   SET_NAMES(__ret_list, __ret_list_names);
   vars_protected += 2;
   UNPROTECT(vars_protected);
@@ -373,6 +459,60 @@ SEXP R_H5Fget_mdc_hit_rate(SEXP R_file_id, SEXP R_hit_rate_ptr){
   return(__ret_list);
 }
 
+/* H5_DLL herr_t H5Fget_mdc_logging_status(hid_t file_id, hbool_t *is_enabled, hbool_t *is_currently_logging); */
+SEXP R_H5Fget_mdc_logging_status(SEXP R_file_id, SEXP R_is_enabled, SEXP R_is_currently_logging){
+  hsize_t size_helper;
+  SEXP R_helper = R_NilValue;
+  int vars_protected=0;
+  R_is_enabled = PROTECT(duplicate(R_is_enabled));
+  vars_protected++;
+  R_is_currently_logging = PROTECT(duplicate(R_is_currently_logging));
+  vars_protected++;
+  hid_t file_id = SEXP_to_longlong(R_file_id, 0);
+  hbool_t* is_enabled;
+  if(XLENGTH(R_is_enabled) == 0) {
+    is_enabled = NULL;
+  }
+  else {
+    R_helper = PROTECT(RToH5(R_is_enabled, h5_datatype[DT_hbool_t], XLENGTH(R_is_enabled)));
+    is_enabled= (hbool_t*) VOIDPTR(R_helper);
+    vars_protected++;
+  }
+  hbool_t* is_currently_logging;
+  if(XLENGTH(R_is_currently_logging) == 0) {
+    is_currently_logging = NULL;
+  }
+  else {
+    R_helper = PROTECT(RToH5(R_is_currently_logging, h5_datatype[DT_hbool_t], XLENGTH(R_is_currently_logging)));
+    is_currently_logging= (hbool_t*) VOIDPTR(R_helper);
+    vars_protected++;
+  }
+  herr_t return_val = H5Fget_mdc_logging_status(file_id, is_enabled, is_currently_logging);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  size_helper = guess_nelem(R_is_enabled, h5_datatype[DT_hbool_t]);
+  R_is_enabled = PROTECT(H5ToR_single_step(is_enabled, h5_datatype[DT_hbool_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  vars_protected++;
+  size_helper = guess_nelem(R_is_currently_logging, h5_datatype[DT_hbool_t]);
+  R_is_currently_logging = PROTECT(H5ToR_single_step(is_currently_logging, h5_datatype[DT_hbool_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 3));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SET_VECTOR_ELT(__ret_list, 1, R_is_enabled);
+  SET_VECTOR_ELT(__ret_list, 2, R_is_currently_logging);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 3));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_STRING_ELT(__ret_list_names, 1, mkChar("is_enabled"));
+  SET_STRING_ELT(__ret_list_names, 2, mkChar("is_currently_logging"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL herr_t H5Fget_mdc_size(hid_t file_id, size_t * max_size_ptr, size_t * min_clean_size_ptr, size_t * cur_size_ptr, int * cur_num_entries_ptr); */
 SEXP R_H5Fget_mdc_size(SEXP R_file_id, SEXP R_max_size_ptr, SEXP R_min_clean_size_ptr, SEXP R_cur_size_ptr, SEXP R_cur_num_entries_ptr){
   hsize_t size_helper;
@@ -459,6 +599,38 @@ SEXP R_H5Fget_mdc_size(SEXP R_file_id, SEXP R_max_size_ptr, SEXP R_min_clean_siz
   return(__ret_list);
 }
 
+/* H5_DLL herr_t H5Fget_metadata_read_retry_info(hid_t file_id, H5F_retry_info_t *info); */
+SEXP R_H5Fget_metadata_read_retry_info(SEXP R_file_id, SEXP R_info){
+  hsize_t size_helper;
+  SEXP R_helper = R_NilValue;
+  int vars_protected=0;
+  R_info = PROTECT(duplicate(R_info));
+  vars_protected++;
+  hid_t file_id = SEXP_to_longlong(R_file_id, 0);
+  R_helper = PROTECT(RToH5(R_info, h5_datatype[DT_H5F_retry_info_t], guess_nelem(R_info, h5_datatype[DT_H5F_retry_info_t])));
+  H5F_retry_info_t* info= (H5F_retry_info_t*) VOIDPTR(R_helper);
+  vars_protected++;
+  herr_t return_val = H5Fget_metadata_read_retry_info(file_id, info);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  size_helper = guess_nelem(R_info, h5_datatype[DT_H5F_retry_info_t]);
+  R_info = PROTECT(H5ToR_single_step(info, h5_datatype[DT_H5F_retry_info_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 2));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SET_VECTOR_ELT(__ret_list, 1, R_info);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_STRING_ELT(__ret_list_names, 1, mkChar("info"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL ssize_t H5Fget_name(hid_t obj_id, char *name, size_t size); */
 SEXP R_H5Fget_name(SEXP R_obj_id, SEXP R_name, SEXP R_size){
   int vars_protected=0;
@@ -698,6 +870,66 @@ SEXP R_H5Fset_mdc_config(SEXP R_file_id, SEXP R_config_ptr){
   return(__ret_list);
 }
 
+/* H5_DLL herr_t H5Fstart_mdc_logging(hid_t file_id); */
+SEXP R_H5Fstart_mdc_logging(SEXP R_file_id){
+  int vars_protected=0;
+  hid_t file_id = SEXP_to_longlong(R_file_id, 0);
+  herr_t return_val = H5Fstart_mdc_logging(file_id);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
+/* H5_DLL herr_t H5Fstart_swmr_write(hid_t file_id); */
+SEXP R_H5Fstart_swmr_write(SEXP R_file_id){
+  int vars_protected=0;
+  hid_t file_id = SEXP_to_longlong(R_file_id, 0);
+  herr_t return_val = H5Fstart_swmr_write(file_id);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
+/* H5_DLL herr_t H5Fstop_mdc_logging(hid_t file_id); */
+SEXP R_H5Fstop_mdc_logging(SEXP R_file_id){
+  int vars_protected=0;
+  hid_t file_id = SEXP_to_longlong(R_file_id, 0);
+  herr_t return_val = H5Fstop_mdc_logging(file_id);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL herr_t H5Funmount(hid_t loc, const char *name); */
 SEXP R_H5Funmount(SEXP R_loc, SEXP R_name){
   int vars_protected=0;
