@@ -19,6 +19,8 @@ SEXP R_H5Dformat_convert(SEXP R_dset_id);
 SEXP R_H5Dget_access_plist(SEXP R_dset_id);
 /* H5_DLL herr_t H5Dget_chunk_index_type(hid_t did, H5D_chunk_index_t *idx_type); */
 SEXP R_H5Dget_chunk_index_type(SEXP R_did, SEXP R_idx_type);
+/* H5_DLL herr_t H5Dget_chunk_storage_size(hid_t dset_id, const hsize_t *offset, hsize_t *chunk_bytes); */
+SEXP R_H5Dget_chunk_storage_size(SEXP R_dset_id, SEXP R_offset, SEXP R_chunk_bytes);
 /* H5_DLL hid_t H5Dget_create_plist(hid_t dset_id); */
 SEXP R_H5Dget_create_plist(SEXP R_dset_id);
 /* H5_DLL haddr_t H5Dget_offset(hid_t dset_id); */
@@ -35,6 +37,8 @@ SEXP R_H5Dget_type(SEXP R_dset_id);
 SEXP R_H5Dopen2(SEXP R_file_id, SEXP R_name, SEXP R_dapl_id);
 /* H5_DLL herr_t H5Dread(hid_t dset_id, hid_t mem_type_id, hid_t mem_space_id, hid_t file_space_id, hid_t plist_id, void *buf); */
 SEXP R_H5Dread(SEXP R_dset_id, SEXP R_mem_type_id, SEXP R_mem_space_id, SEXP R_file_space_id, SEXP R_plist_id, SEXP R_buf, SEXP _dupl_buf);
+/* H5_DLL herr_t H5Dread_chunk(hid_t dset_id, hid_t dxpl_id, const hsize_t *offset, uint32_t *filters, void *buf); */
+SEXP R_H5Dread_chunk(SEXP R_dset_id, SEXP R_dxpl_id, SEXP R_offset, SEXP R_filters, SEXP R_buf, SEXP _dupl_buf);
 /* H5_DLL herr_t H5Drefresh(hid_t dset_id); */
 SEXP R_H5Drefresh(SEXP R_dset_id);
 /* H5_DLL herr_t H5Dset_extent(hid_t dset_id, const hsize_t size[]); */
@@ -45,4 +49,6 @@ SEXP R_H5Dvlen_get_buf_size(SEXP R_dataset_id, SEXP R_type_id, SEXP R_space_id,
 SEXP R_H5Dvlen_reclaim(SEXP R_type_id, SEXP R_space_id, SEXP R_plist_id, SEXP R_buf, SEXP _dupl_buf);
 /* H5_DLL herr_t H5Dwrite(hid_t dset_id, hid_t mem_type_id, hid_t mem_space_id, hid_t file_space_id, hid_t plist_id, const void *buf); */
 SEXP R_H5Dwrite(SEXP R_dset_id, SEXP R_mem_type_id, SEXP R_mem_space_id, SEXP R_file_space_id, SEXP R_plist_id, SEXP R_buf);
+/* H5_DLL herr_t H5Dwrite_chunk(hid_t dset_id, hid_t dxpl_id, uint32_t filters, const hsize_t *offset, size_t data_size, const void *buf); */
+SEXP R_H5Dwrite_chunk(SEXP R_dset_id, SEXP R_dxpl_id, SEXP R_filters, SEXP R_offset, SEXP R_data_size, SEXP R_buf);
 #endif
