@@ -4,8 +4,10 @@ R_CallMethodDef library_WRAPPER_AUTO_H5[] = {
 {"R_H5check_version", (DL_FUNC) &R_H5check_version, 3},
 {"R_H5close", (DL_FUNC) &R_H5close, 0},
 {"R_H5dont_atexit", (DL_FUNC) &R_H5dont_atexit, 0},
+{"R_H5free_memory", (DL_FUNC) &R_H5free_memory, 2},
 {"R_H5garbage_collect", (DL_FUNC) &R_H5garbage_collect, 0},
 {"R_H5get_libversion", (DL_FUNC) &R_H5get_libversion, 3},
+{"R_H5is_library_threadsafe", (DL_FUNC) &R_H5is_library_threadsafe, 1},
 {"R_H5open", (DL_FUNC) &R_H5open, 0},
 {"R_H5set_free_list_limits", (DL_FUNC) &R_H5set_free_list_limits, 6},
 {NULL, NULL, 0}
@@ -48,7 +50,11 @@ R_CallMethodDef library_WRAPPER_AUTO_H5D[] = {
 {"R_H5Dcreate2", (DL_FUNC) &R_H5Dcreate2, 7},
 {"R_H5Ddebug", (DL_FUNC) &R_H5Ddebug, 1},
 {"R_H5Dfill", (DL_FUNC) &R_H5Dfill, 6},
+{"R_H5Dflush", (DL_FUNC) &R_H5Dflush, 1},
+{"R_H5Dformat_convert", (DL_FUNC) &R_H5Dformat_convert, 1},
 {"R_H5Dget_access_plist", (DL_FUNC) &R_H5Dget_access_plist, 1},
+{"R_H5Dget_chunk_index_type", (DL_FUNC) &R_H5Dget_chunk_index_type, 2},
+{"R_H5Dget_chunk_storage_size", (DL_FUNC) &R_H5Dget_chunk_storage_size, 3},
 {"R_H5Dget_create_plist", (DL_FUNC) &R_H5Dget_create_plist, 1},
 {"R_H5Dget_offset", (DL_FUNC) &R_H5Dget_offset, 1},
 {"R_H5Dget_space", (DL_FUNC) &R_H5Dget_space, 1},
@@ -57,10 +63,13 @@ R_CallMethodDef library_WRAPPER_AUTO_H5D[] = {
 {"R_H5Dget_type", (DL_FUNC) &R_H5Dget_type, 1},
 {"R_H5Dopen2", (DL_FUNC) &R_H5Dopen2, 3},
 {"R_H5Dread", (DL_FUNC) &R_H5Dread, 7},
+{"R_H5Dread_chunk", (DL_FUNC) &R_H5Dread_chunk, 6},
+{"R_H5Drefresh", (DL_FUNC) &R_H5Drefresh, 1},
 {"R_H5Dset_extent", (DL_FUNC) &R_H5Dset_extent, 2},
 {"R_H5Dvlen_get_buf_size", (DL_FUNC) &R_H5Dvlen_get_buf_size, 4},
 {"R_H5Dvlen_reclaim", (DL_FUNC) &R_H5Dvlen_reclaim, 5},
 {"R_H5Dwrite", (DL_FUNC) &R_H5Dwrite, 6},
+{"R_H5Dwrite_chunk", (DL_FUNC) &R_H5Dwrite_chunk, 6},
 {NULL, NULL, 0}
 };
 
@@ -103,31 +112,45 @@ R_CallMethodDef library_WRAPPER_AUTO_H5F[] = {
 {"R_H5Fclose", (DL_FUNC) &R_H5Fclose, 1},
 {"R_H5Fcreate", (DL_FUNC) &R_H5Fcreate, 4},
 {"R_H5Fflush", (DL_FUNC) &R_H5Fflush, 2},
+{"R_H5Fformat_convert", (DL_FUNC) &R_H5Fformat_convert, 1},
 {"R_H5Fget_access_plist", (DL_FUNC) &R_H5Fget_access_plist, 1},
 {"R_H5Fget_create_plist", (DL_FUNC) &R_H5Fget_create_plist, 1},
+{"R_H5Fget_eoa", (DL_FUNC) &R_H5Fget_eoa, 2},
 {"R_H5Fget_file_image", (DL_FUNC) &R_H5Fget_file_image, 4},
 {"R_H5Fget_filesize", (DL_FUNC) &R_H5Fget_filesize, 2},
+{"R_H5Fget_free_sections", (DL_FUNC) &R_H5Fget_free_sections, 4},
 {"R_H5Fget_freespace", (DL_FUNC) &R_H5Fget_freespace, 1},
-{"R_H5Fget_info", (DL_FUNC) &R_H5Fget_info, 2},
+{"R_H5Fget_info1", (DL_FUNC) &R_H5Fget_info1, 2},
+{"R_H5Fget_info2", (DL_FUNC) &R_H5Fget_info2, 2},
 {"R_H5Fget_intent", (DL_FUNC) &R_H5Fget_intent, 2},
 {"R_H5Fget_mdc_config", (DL_FUNC) &R_H5Fget_mdc_config, 2},
 {"R_H5Fget_mdc_hit_rate", (DL_FUNC) &R_H5Fget_mdc_hit_rate, 2},
+{"R_H5Fget_mdc_image_info", (DL_FUNC) &R_H5Fget_mdc_image_info, 3},
+{"R_H5Fget_mdc_logging_status", (DL_FUNC) &R_H5Fget_mdc_logging_status, 3},
 {"R_H5Fget_mdc_size", (DL_FUNC) &R_H5Fget_mdc_size, 5},
+{"R_H5Fget_metadata_read_retry_info", (DL_FUNC) &R_H5Fget_metadata_read_retry_info, 2},
 {"R_H5Fget_name", (DL_FUNC) &R_H5Fget_name, 3},
 {"R_H5Fget_obj_count", (DL_FUNC) &R_H5Fget_obj_count, 2},
 {"R_H5Fget_obj_ids", (DL_FUNC) &R_H5Fget_obj_ids, 4},
+{"R_H5Fget_page_buffering_stats", (DL_FUNC) &R_H5Fget_page_buffering_stats, 6},
+{"R_H5Fincrement_filesize", (DL_FUNC) &R_H5Fincrement_filesize, 2},
 {"R_H5Fis_hdf5", (DL_FUNC) &R_H5Fis_hdf5, 1},
 {"R_H5Fmount", (DL_FUNC) &R_H5Fmount, 4},
 {"R_H5Fopen", (DL_FUNC) &R_H5Fopen, 3},
 {"R_H5Freopen", (DL_FUNC) &R_H5Freopen, 1},
 {"R_H5Freset_mdc_hit_rate_stats", (DL_FUNC) &R_H5Freset_mdc_hit_rate_stats, 1},
+{"R_H5Freset_page_buffering_stats", (DL_FUNC) &R_H5Freset_page_buffering_stats, 1},
+{"R_H5Fset_latest_format", (DL_FUNC) &R_H5Fset_latest_format, 2},
+{"R_H5Fset_libver_bounds", (DL_FUNC) &R_H5Fset_libver_bounds, 3},
 {"R_H5Fset_mdc_config", (DL_FUNC) &R_H5Fset_mdc_config, 2},
+{"R_H5Fstart_mdc_logging", (DL_FUNC) &R_H5Fstart_mdc_logging, 1},
+{"R_H5Fstart_swmr_write", (DL_FUNC) &R_H5Fstart_swmr_write, 1},
+{"R_H5Fstop_mdc_logging", (DL_FUNC) &R_H5Fstop_mdc_logging, 1},
 {"R_H5Funmount", (DL_FUNC) &R_H5Funmount, 2},
 {NULL, NULL, 0}
 };
 
 R_CallMethodDef library_WRAPPER_AUTO_H5FDCORE[] = {
-{"R_H5FD_core_term", (DL_FUNC) &R_H5FD_core_term, 0},
 {"R_H5Pget_fapl_core", (DL_FUNC) &R_H5Pget_fapl_core, 3},
 {"R_H5Pset_fapl_core", (DL_FUNC) &R_H5Pset_fapl_core, 3},
 {NULL, NULL, 0}
@@ -135,7 +158,6 @@ R_CallMethodDef library_WRAPPER_AUTO_H5FDCORE[] = {
 
 R_CallMethodDef library_WRAPPER_AUTO_H5FDFAMILY[] = {
 {"R_H5FD_family_init", (DL_FUNC) &R_H5FD_family_init, 0},
-{"R_H5FD_family_term", (DL_FUNC) &R_H5FD_family_term, 0},
 {"R_H5Pget_fapl_family", (DL_FUNC) &R_H5Pget_fapl_family, 3},
 {"R_H5Pset_fapl_family", (DL_FUNC) &R_H5Pset_fapl_family, 3},
 {NULL, NULL, 0}
@@ -143,21 +165,18 @@ R_CallMethodDef library_WRAPPER_AUTO_H5FDFAMILY[] = {
 
 R_CallMethodDef library_WRAPPER_AUTO_H5FDLOG[] = {
 {"R_H5FD_log_init", (DL_FUNC) &R_H5FD_log_init, 0},
-{"R_H5FD_log_term", (DL_FUNC) &R_H5FD_log_term, 0},
 {"R_H5Pset_fapl_log", (DL_FUNC) &R_H5Pset_fapl_log, 4},
 {NULL, NULL, 0}
 };
 
 R_CallMethodDef library_WRAPPER_AUTO_H5FDSEC2[] = {
 {"R_H5FD_sec2_init", (DL_FUNC) &R_H5FD_sec2_init, 0},
-{"R_H5FD_sec2_term", (DL_FUNC) &R_H5FD_sec2_term, 0},
 {"R_H5Pset_fapl_sec2", (DL_FUNC) &R_H5Pset_fapl_sec2, 1},
 {NULL, NULL, 0}
 };
 
 R_CallMethodDef library_WRAPPER_AUTO_H5FDSTDIO[] = {
 {"R_H5FD_stdio_init", (DL_FUNC) &R_H5FD_stdio_init, 0},
-{"R_H5FD_stdio_term", (DL_FUNC) &R_H5FD_stdio_term, 0},
 {"R_H5Pset_fapl_stdio", (DL_FUNC) &R_H5Pset_fapl_stdio, 1},
 {NULL, NULL, 0}
 };
@@ -166,11 +185,13 @@ R_CallMethodDef library_WRAPPER_AUTO_H5G[] = {
 {"R_H5Gclose", (DL_FUNC) &R_H5Gclose, 1},
 {"R_H5Gcreate_anon", (DL_FUNC) &R_H5Gcreate_anon, 3},
 {"R_H5Gcreate2", (DL_FUNC) &R_H5Gcreate2, 5},
+{"R_H5Gflush", (DL_FUNC) &R_H5Gflush, 1},
 {"R_H5Gget_create_plist", (DL_FUNC) &R_H5Gget_create_plist, 1},
 {"R_H5Gget_info", (DL_FUNC) &R_H5Gget_info, 2},
 {"R_H5Gget_info_by_idx", (DL_FUNC) &R_H5Gget_info_by_idx, 7},
 {"R_H5Gget_info_by_name", (DL_FUNC) &R_H5Gget_info_by_name, 4},
 {"R_H5Gopen2", (DL_FUNC) &R_H5Gopen2, 3},
+{"R_H5Grefresh", (DL_FUNC) &R_H5Grefresh, 1},
 {"R_H5Gset_comment", (DL_FUNC) &R_H5Gset_comment, 3},
 {NULL, NULL, 0}
 };
@@ -287,20 +308,28 @@ R_CallMethodDef library_WRAPPER_AUTO_H5LT[] = {
 };
 
 R_CallMethodDef library_WRAPPER_AUTO_H5O[] = {
+{"R_H5Oare_mdc_flushes_disabled", (DL_FUNC) &R_H5Oare_mdc_flushes_disabled, 2},
 {"R_H5Oclose", (DL_FUNC) &R_H5Oclose, 1},
 {"R_H5Ocopy", (DL_FUNC) &R_H5Ocopy, 6},
 {"R_H5Odecr_refcount", (DL_FUNC) &R_H5Odecr_refcount, 1},
+{"R_H5Odisable_mdc_flushes", (DL_FUNC) &R_H5Odisable_mdc_flushes, 1},
+{"R_H5Oenable_mdc_flushes", (DL_FUNC) &R_H5Oenable_mdc_flushes, 1},
 {"R_H5Oexists_by_name", (DL_FUNC) &R_H5Oexists_by_name, 3},
+{"R_H5Oflush", (DL_FUNC) &R_H5Oflush, 1},
 {"R_H5Oget_comment", (DL_FUNC) &R_H5Oget_comment, 3},
 {"R_H5Oget_comment_by_name", (DL_FUNC) &R_H5Oget_comment_by_name, 5},
-{"R_H5Oget_info", (DL_FUNC) &R_H5Oget_info, 2},
-{"R_H5Oget_info_by_idx", (DL_FUNC) &R_H5Oget_info_by_idx, 7},
-{"R_H5Oget_info_by_name", (DL_FUNC) &R_H5Oget_info_by_name, 4},
+{"R_H5Oget_info_by_idx1", (DL_FUNC) &R_H5Oget_info_by_idx1, 7},
+{"R_H5Oget_info_by_idx2", (DL_FUNC) &R_H5Oget_info_by_idx2, 8},
+{"R_H5Oget_info_by_name1", (DL_FUNC) &R_H5Oget_info_by_name1, 4},
+{"R_H5Oget_info_by_name2", (DL_FUNC) &R_H5Oget_info_by_name2, 5},
+{"R_H5Oget_info1", (DL_FUNC) &R_H5Oget_info1, 2},
+{"R_H5Oget_info2", (DL_FUNC) &R_H5Oget_info2, 3},
 {"R_H5Oincr_refcount", (DL_FUNC) &R_H5Oincr_refcount, 1},
 {"R_H5Olink", (DL_FUNC) &R_H5Olink, 5},
 {"R_H5Oopen", (DL_FUNC) &R_H5Oopen, 3},
 {"R_H5Oopen_by_addr", (DL_FUNC) &R_H5Oopen_by_addr, 2},
 {"R_H5Oopen_by_idx", (DL_FUNC) &R_H5Oopen_by_idx, 6},
+{"R_H5Orefresh", (DL_FUNC) &R_H5Orefresh, 1},
 {"R_H5Oset_comment", (DL_FUNC) &R_H5Oset_comment, 2},
 {"R_H5Oset_comment_by_name", (DL_FUNC) &R_H5Oset_comment_by_name, 4},
 {NULL, NULL, 0}
@@ -314,6 +343,8 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pcopy", (DL_FUNC) &R_H5Pcopy, 1},
 {"R_H5Pcopy_prop", (DL_FUNC) &R_H5Pcopy_prop, 3},
 {"R_H5Pcreate", (DL_FUNC) &R_H5Pcreate, 1},
+{"R_H5Pdecode", (DL_FUNC) &R_H5Pdecode, 1},
+{"R_H5Pencode", (DL_FUNC) &R_H5Pencode, 4},
 {"R_H5Pequal", (DL_FUNC) &R_H5Pequal, 2},
 {"R_H5Pexist", (DL_FUNC) &R_H5Pexist, 2},
 {"R_H5Pfill_value_defined", (DL_FUNC) &R_H5Pfill_value_defined, 2},
@@ -328,23 +359,30 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pget_char_encoding", (DL_FUNC) &R_H5Pget_char_encoding, 2},
 {"R_H5Pget_chunk", (DL_FUNC) &R_H5Pget_chunk, 3},
 {"R_H5Pget_chunk_cache", (DL_FUNC) &R_H5Pget_chunk_cache, 4},
+{"R_H5Pget_chunk_opts", (DL_FUNC) &R_H5Pget_chunk_opts, 2},
 {"R_H5Pget_class", (DL_FUNC) &R_H5Pget_class, 1},
 {"R_H5Pget_class_name", (DL_FUNC) &R_H5Pget_class_name, 1},
 {"R_H5Pget_class_parent", (DL_FUNC) &R_H5Pget_class_parent, 1},
 {"R_H5Pget_copy_object", (DL_FUNC) &R_H5Pget_copy_object, 2},
+{"R_H5Pget_core_write_tracking", (DL_FUNC) &R_H5Pget_core_write_tracking, 3},
 {"R_H5Pget_create_intermediate_group", (DL_FUNC) &R_H5Pget_create_intermediate_group, 2},
 {"R_H5Pget_data_transform", (DL_FUNC) &R_H5Pget_data_transform, 3},
 {"R_H5Pget_driver", (DL_FUNC) &R_H5Pget_driver, 1},
 {"R_H5Pget_edc_check", (DL_FUNC) &R_H5Pget_edc_check, 1},
+{"R_H5Pget_efile_prefix", (DL_FUNC) &R_H5Pget_efile_prefix, 3},
 {"R_H5Pget_elink_acc_flags", (DL_FUNC) &R_H5Pget_elink_acc_flags, 2},
 {"R_H5Pget_elink_fapl", (DL_FUNC) &R_H5Pget_elink_fapl, 1},
 {"R_H5Pget_elink_file_cache_size", (DL_FUNC) &R_H5Pget_elink_file_cache_size, 2},
 {"R_H5Pget_elink_prefix", (DL_FUNC) &R_H5Pget_elink_prefix, 3},
 {"R_H5Pget_est_link_info", (DL_FUNC) &R_H5Pget_est_link_info, 3},
+{"R_H5Pget_evict_on_close", (DL_FUNC) &R_H5Pget_evict_on_close, 2},
 {"R_H5Pget_external", (DL_FUNC) &R_H5Pget_external, 6},
 {"R_H5Pget_external_count", (DL_FUNC) &R_H5Pget_external_count, 1},
 {"R_H5Pget_family_offset", (DL_FUNC) &R_H5Pget_family_offset, 2},
 {"R_H5Pget_fclose_degree", (DL_FUNC) &R_H5Pget_fclose_degree, 2},
+{"R_H5Pget_file_space", (DL_FUNC) &R_H5Pget_file_space, 3},
+{"R_H5Pget_file_space_page_size", (DL_FUNC) &R_H5Pget_file_space_page_size, 2},
+{"R_H5Pget_file_space_strategy", (DL_FUNC) &R_H5Pget_file_space_strategy, 4},
 {"R_H5Pget_fill_time", (DL_FUNC) &R_H5Pget_fill_time, 2},
 {"R_H5Pget_fill_value", (DL_FUNC) &R_H5Pget_fill_value, 4},
 {"R_H5Pget_filter_by_id2", (DL_FUNC) &R_H5Pget_filter_by_id2, 8},
@@ -358,12 +396,16 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pget_link_phase_change", (DL_FUNC) &R_H5Pget_link_phase_change, 3},
 {"R_H5Pget_local_heap_size_hint", (DL_FUNC) &R_H5Pget_local_heap_size_hint, 2},
 {"R_H5Pget_mdc_config ", (DL_FUNC) &R_H5Pget_mdc_config , 2},
+{"R_H5Pget_mdc_image_config", (DL_FUNC) &R_H5Pget_mdc_image_config, 2},
+{"R_H5Pget_mdc_log_options", (DL_FUNC) &R_H5Pget_mdc_log_options, 5},
 {"R_H5Pget_meta_block_size", (DL_FUNC) &R_H5Pget_meta_block_size, 2},
+{"R_H5Pget_metadata_read_attempts", (DL_FUNC) &R_H5Pget_metadata_read_attempts, 2},
 {"R_H5Pget_multi_type", (DL_FUNC) &R_H5Pget_multi_type, 2},
 {"R_H5Pget_nfilters", (DL_FUNC) &R_H5Pget_nfilters, 1},
 {"R_H5Pget_nlinks", (DL_FUNC) &R_H5Pget_nlinks, 2},
 {"R_H5Pget_nprops", (DL_FUNC) &R_H5Pget_nprops, 2},
 {"R_H5Pget_obj_track_times", (DL_FUNC) &R_H5Pget_obj_track_times, 2},
+{"R_H5Pget_page_buffer_size", (DL_FUNC) &R_H5Pget_page_buffer_size, 4},
 {"R_H5Pget_preserve", (DL_FUNC) &R_H5Pget_preserve, 1},
 {"R_H5Pget_shared_mesg_index", (DL_FUNC) &R_H5Pget_shared_mesg_index, 4},
 {"R_H5Pget_shared_mesg_nindexes", (DL_FUNC) &R_H5Pget_shared_mesg_nindexes, 2},
@@ -375,11 +417,19 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pget_sym_k", (DL_FUNC) &R_H5Pget_sym_k, 3},
 {"R_H5Pget_userblock", (DL_FUNC) &R_H5Pget_userblock, 2},
 {"R_H5Pget_version", (DL_FUNC) &R_H5Pget_version, 5},
+{"R_H5Pget_virtual_count", (DL_FUNC) &R_H5Pget_virtual_count, 2},
+{"R_H5Pget_virtual_dsetname", (DL_FUNC) &R_H5Pget_virtual_dsetname, 4},
+{"R_H5Pget_virtual_filename", (DL_FUNC) &R_H5Pget_virtual_filename, 4},
+{"R_H5Pget_virtual_prefix", (DL_FUNC) &R_H5Pget_virtual_prefix, 3},
+{"R_H5Pget_virtual_printf_gap", (DL_FUNC) &R_H5Pget_virtual_printf_gap, 2},
+{"R_H5Pget_virtual_srcspace", (DL_FUNC) &R_H5Pget_virtual_srcspace, 2},
+{"R_H5Pget_virtual_view", (DL_FUNC) &R_H5Pget_virtual_view, 2},
+{"R_H5Pget_virtual_vspace", (DL_FUNC) &R_H5Pget_virtual_vspace, 2},
 {"R_H5Pisa_class", (DL_FUNC) &R_H5Pisa_class, 2},
 {"R_H5Pmodify_filter", (DL_FUNC) &R_H5Pmodify_filter, 5},
 {"R_H5Premove", (DL_FUNC) &R_H5Premove, 2},
 {"R_H5Premove_filter", (DL_FUNC) &R_H5Premove_filter, 2},
-{"R_H5Pset", (DL_FUNC) &R_H5Pset, 4},
+{"R_H5Pset", (DL_FUNC) &R_H5Pset, 3},
 {"R_H5Pset_alignment", (DL_FUNC) &R_H5Pset_alignment, 3},
 {"R_H5Pset_alloc_time", (DL_FUNC) &R_H5Pset_alloc_time, 2},
 {"R_H5Pset_attr_creation_order", (DL_FUNC) &R_H5Pset_attr_creation_order, 2},
@@ -390,21 +440,28 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pset_char_encoding", (DL_FUNC) &R_H5Pset_char_encoding, 2},
 {"R_H5Pset_chunk", (DL_FUNC) &R_H5Pset_chunk, 3},
 {"R_H5Pset_chunk_cache", (DL_FUNC) &R_H5Pset_chunk_cache, 4},
+{"R_H5Pset_chunk_opts", (DL_FUNC) &R_H5Pset_chunk_opts, 2},
 {"R_H5Pset_copy_object", (DL_FUNC) &R_H5Pset_copy_object, 2},
+{"R_H5Pset_core_write_tracking", (DL_FUNC) &R_H5Pset_core_write_tracking, 3},
 {"R_H5Pset_create_intermediate_group", (DL_FUNC) &R_H5Pset_create_intermediate_group, 2},
 {"R_H5Pset_data_transform", (DL_FUNC) &R_H5Pset_data_transform, 2},
 {"R_H5Pset_deflate", (DL_FUNC) &R_H5Pset_deflate, 2},
 {"R_H5Pset_driver", (DL_FUNC) &R_H5Pset_driver, 3},
 {"R_H5Pset_edc_check", (DL_FUNC) &R_H5Pset_edc_check, 2},
+{"R_H5Pset_efile_prefix", (DL_FUNC) &R_H5Pset_efile_prefix, 2},
 {"R_H5Pset_elink_acc_flags", (DL_FUNC) &R_H5Pset_elink_acc_flags, 2},
 {"R_H5Pset_elink_fapl", (DL_FUNC) &R_H5Pset_elink_fapl, 2},
 {"R_H5Pset_elink_file_cache_size", (DL_FUNC) &R_H5Pset_elink_file_cache_size, 2},
 {"R_H5Pset_elink_prefix", (DL_FUNC) &R_H5Pset_elink_prefix, 2},
 {"R_H5Pset_est_link_info", (DL_FUNC) &R_H5Pset_est_link_info, 3},
+{"R_H5Pset_evict_on_close", (DL_FUNC) &R_H5Pset_evict_on_close, 2},
 {"R_H5Pset_external", (DL_FUNC) &R_H5Pset_external, 4},
 {"R_H5Pset_family_offset", (DL_FUNC) &R_H5Pset_family_offset, 2},
 {"R_H5Pset_fclose_degree", (DL_FUNC) &R_H5Pset_fclose_degree, 2},
 {"R_H5Pset_file_image", (DL_FUNC) &R_H5Pset_file_image, 4},
+{"R_H5Pset_file_space", (DL_FUNC) &R_H5Pset_file_space, 3},
+{"R_H5Pset_file_space_page_size", (DL_FUNC) &R_H5Pset_file_space_page_size, 2},
+{"R_H5Pset_file_space_strategy", (DL_FUNC) &R_H5Pset_file_space_strategy, 4},
 {"R_H5Pset_fill_time", (DL_FUNC) &R_H5Pset_fill_time, 2},
 {"R_H5Pset_fill_value", (DL_FUNC) &R_H5Pset_fill_value, 3},
 {"R_H5Pset_filter", (DL_FUNC) &R_H5Pset_filter, 5},
@@ -418,11 +475,15 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pset_link_phase_change", (DL_FUNC) &R_H5Pset_link_phase_change, 3},
 {"R_H5Pset_local_heap_size_hint", (DL_FUNC) &R_H5Pset_local_heap_size_hint, 2},
 {"R_H5Pset_mdc_config", (DL_FUNC) &R_H5Pset_mdc_config, 2},
+{"R_H5Pset_mdc_image_config", (DL_FUNC) &R_H5Pset_mdc_image_config, 2},
+{"R_H5Pset_mdc_log_options", (DL_FUNC) &R_H5Pset_mdc_log_options, 4},
 {"R_H5Pset_meta_block_size", (DL_FUNC) &R_H5Pset_meta_block_size, 2},
+{"R_H5Pset_metadata_read_attempts", (DL_FUNC) &R_H5Pset_metadata_read_attempts, 2},
 {"R_H5Pset_multi_type", (DL_FUNC) &R_H5Pset_multi_type, 2},
 {"R_H5Pset_nbit", (DL_FUNC) &R_H5Pset_nbit, 1},
 {"R_H5Pset_nlinks", (DL_FUNC) &R_H5Pset_nlinks, 2},
 {"R_H5Pset_obj_track_times", (DL_FUNC) &R_H5Pset_obj_track_times, 2},
+{"R_H5Pset_page_buffer_size", (DL_FUNC) &R_H5Pset_page_buffer_size, 4},
 {"R_H5Pset_preserve", (DL_FUNC) &R_H5Pset_preserve, 2},
 {"R_H5Pset_scaleoffset", (DL_FUNC) &R_H5Pset_scaleoffset, 3},
 {"R_H5Pset_shared_mesg_index", (DL_FUNC) &R_H5Pset_shared_mesg_index, 4},
@@ -435,13 +496,18 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pset_sym_k", (DL_FUNC) &R_H5Pset_sym_k, 3},
 {"R_H5Pset_szip", (DL_FUNC) &R_H5Pset_szip, 3},
 {"R_H5Pset_userblock", (DL_FUNC) &R_H5Pset_userblock, 2},
+{"R_H5Pset_virtual", (DL_FUNC) &R_H5Pset_virtual, 5},
+{"R_H5Pset_virtual_prefix", (DL_FUNC) &R_H5Pset_virtual_prefix, 2},
+{"R_H5Pset_virtual_printf_gap", (DL_FUNC) &R_H5Pset_virtual_printf_gap, 2},
+{"R_H5Pset_virtual_view", (DL_FUNC) &R_H5Pset_virtual_view, 2},
 {"R_H5Punregister", (DL_FUNC) &R_H5Punregister, 2},
 {NULL, NULL, 0}
 };
 
 R_CallMethodDef library_WRAPPER_AUTO_H5R[] = {
 {"R_H5Rcreate", (DL_FUNC) &R_H5Rcreate, 6},
-{"R_H5Rdereference", (DL_FUNC) &R_H5Rdereference, 3},
+{"R_H5Rdereference1", (DL_FUNC) &R_H5Rdereference1, 3},
+{"R_H5Rdereference2", (DL_FUNC) &R_H5Rdereference2, 4},
 {"R_H5Rget_name", (DL_FUNC) &R_H5Rget_name, 5},
 {"R_H5Rget_obj_type2", (DL_FUNC) &R_H5Rget_obj_type2, 4},
 {"R_H5Rget_region", (DL_FUNC) &R_H5Rget_region, 3},
@@ -457,6 +523,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5S[] = {
 {"R_H5Sencode", (DL_FUNC) &R_H5Sencode, 4},
 {"R_H5Sextent_copy", (DL_FUNC) &R_H5Sextent_copy, 2},
 {"R_H5Sextent_equal", (DL_FUNC) &R_H5Sextent_equal, 2},
+{"R_H5Sget_regular_hyperslab", (DL_FUNC) &R_H5Sget_regular_hyperslab, 5},
 {"R_H5Sget_select_bounds", (DL_FUNC) &R_H5Sget_select_bounds, 3},
 {"R_H5Sget_select_elem_npoints", (DL_FUNC) &R_H5Sget_select_elem_npoints, 1},
 {"R_H5Sget_select_elem_pointlist", (DL_FUNC) &R_H5Sget_select_elem_pointlist, 4},
@@ -468,6 +535,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5S[] = {
 {"R_H5Sget_simple_extent_ndims", (DL_FUNC) &R_H5Sget_simple_extent_ndims, 1},
 {"R_H5Sget_simple_extent_npoints", (DL_FUNC) &R_H5Sget_simple_extent_npoints, 1},
 {"R_H5Sget_simple_extent_type", (DL_FUNC) &R_H5Sget_simple_extent_type, 1},
+{"R_H5Sis_regular_hyperslab", (DL_FUNC) &R_H5Sis_regular_hyperslab, 1},
 {"R_H5Sis_simple", (DL_FUNC) &R_H5Sis_simple, 1},
 {"R_H5Soffset_simple", (DL_FUNC) &R_H5Soffset_simple, 2},
 {"R_H5Sselect_all", (DL_FUNC) &R_H5Sselect_all, 1},
@@ -498,6 +566,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5T[] = {
 {"R_H5Tenum_nameof", (DL_FUNC) &R_H5Tenum_nameof, 4},
 {"R_H5Tenum_valueof", (DL_FUNC) &R_H5Tenum_valueof, 4},
 {"R_H5Tequal", (DL_FUNC) &R_H5Tequal, 2},
+{"R_H5Tflush", (DL_FUNC) &R_H5Tflush, 1},
 {"R_H5Tget_array_dims2", (DL_FUNC) &R_H5Tget_array_dims2, 2},
 {"R_H5Tget_array_ndims", (DL_FUNC) &R_H5Tget_array_ndims, 1},
 {"R_H5Tget_class", (DL_FUNC) &R_H5Tget_class, 1},
@@ -529,6 +598,7 @@ R_CallMethodDef library_WRAPPER_AUTO_H5T[] = {
 {"R_H5Tlock", (DL_FUNC) &R_H5Tlock, 1},
 {"R_H5Topen2", (DL_FUNC) &R_H5Topen2, 3},
 {"R_H5Tpack", (DL_FUNC) &R_H5Tpack, 1},
+{"R_H5Trefresh", (DL_FUNC) &R_H5Trefresh, 1},
 {"R_H5Tset_cset", (DL_FUNC) &R_H5Tset_cset, 2},
 {"R_H5Tset_ebias", (DL_FUNC) &R_H5Tset_ebias, 2},
 {"R_H5Tset_fields", (DL_FUNC) &R_H5Tset_fields, 6},
