@@ -17,44 +17,6 @@
  *************************************************************************/
 
 #include "Wrapper_auto_H5O.h"
-/* H5_DLL herr_t H5Oare_mdc_flushes_disabled(hid_t object_id, hbool_t *are_disabled); */
-SEXP R_H5Oare_mdc_flushes_disabled(SEXP R_object_id, SEXP R_are_disabled){
-  hsize_t size_helper;
-  SEXP R_helper = R_NilValue;
-  int vars_protected=0;
-  R_are_disabled = PROTECT(duplicate(R_are_disabled));
-  vars_protected++;
-  hid_t object_id = SEXP_to_longlong(R_object_id, 0);
-  hbool_t* are_disabled;
-  if(XLENGTH(R_are_disabled) == 0) {
-    are_disabled = NULL;
-  }
-  else {
-    R_helper = PROTECT(RToH5(R_are_disabled, h5_datatype[DT_hbool_t], XLENGTH(R_are_disabled)));
-    are_disabled= (hbool_t*) VOIDPTR(R_helper);
-    vars_protected++;
-  }
-  herr_t return_val = H5Oare_mdc_flushes_disabled(object_id, are_disabled);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  size_helper = guess_nelem(R_are_disabled, h5_datatype[DT_hbool_t]);
-  R_are_disabled = PROTECT(H5ToR_single_step(are_disabled, h5_datatype[DT_hbool_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 2));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SET_VECTOR_ELT(__ret_list, 1, R_are_disabled);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_STRING_ELT(__ret_list_names, 1, mkChar("are_disabled"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
 /* H5_DLL herr_t H5Oclose(hid_t object_id); */
 SEXP R_H5Oclose(SEXP R_object_id){
   int vars_protected=0;
@@ -120,46 +82,6 @@ SEXP R_H5Odecr_refcount(SEXP R_object_id){
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Odisable_mdc_flushes(hid_t object_id); */
-SEXP R_H5Odisable_mdc_flushes(SEXP R_object_id){
-  int vars_protected=0;
-  hid_t object_id = SEXP_to_longlong(R_object_id, 0);
-  herr_t return_val = H5Odisable_mdc_flushes(object_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 1));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
-/* H5_DLL herr_t H5Oenable_mdc_flushes(hid_t object_id); */
-SEXP R_H5Oenable_mdc_flushes(SEXP R_object_id){
-  int vars_protected=0;
-  hid_t object_id = SEXP_to_longlong(R_object_id, 0);
-  herr_t return_val = H5Oenable_mdc_flushes(object_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 1));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
 /* H5_DLL htri_t H5Oexists_by_name(hid_t loc_id, const char *name, hid_t lapl_id); */
 SEXP R_H5Oexists_by_name(SEXP R_loc_id, SEXP R_name, SEXP R_lapl_id){
   int vars_protected=0;
@@ -182,26 +104,6 @@ SEXP R_H5Oexists_by_name(SEXP R_loc_id, SEXP R_name, SEXP R_lapl_id){
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Oflush(hid_t obj_id); */
-SEXP R_H5Oflush(SEXP R_obj_id){
-  int vars_protected=0;
-  hid_t obj_id = SEXP_to_longlong(R_obj_id, 0);
-  herr_t return_val = H5Oflush(obj_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 1));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
 /* H5_DLL ssize_t H5Oget_comment(hid_t obj_id, char *comment, size_t bufsize); */
 SEXP R_H5Oget_comment(SEXP R_obj_id, SEXP R_comment, SEXP R_bufsize){
   int vars_protected=0;
@@ -286,8 +188,40 @@ SEXP R_H5Oget_comment_by_name(SEXP R_loc_id, SEXP R_name, SEXP R_comment, SEXP R
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Oget_info_by_idx1(hid_t loc_id, const char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5O_info_t *oinfo, hid_t lapl_id); */
-SEXP R_H5Oget_info_by_idx1(SEXP R_loc_id, SEXP R_group_name, SEXP R_idx_type, SEXP R_order, SEXP R_n, SEXP R_oinfo, SEXP R_lapl_id){
+/* H5_DLL herr_t H5Oget_info(hid_t loc_id, H5O_info_t *oinfo); */
+SEXP R_H5Oget_info(SEXP R_loc_id, SEXP R_oinfo){
+  hsize_t size_helper;
+  SEXP R_helper = R_NilValue;
+  int vars_protected=0;
+  R_oinfo = PROTECT(duplicate(R_oinfo));
+  vars_protected++;
+  hid_t loc_id = SEXP_to_longlong(R_loc_id, 0);
+  R_helper = PROTECT(RToH5(R_oinfo, h5_datatype[DT_H5O_info_t], guess_nelem(R_oinfo, h5_datatype[DT_H5O_info_t])));
+  H5O_info_t* oinfo= (H5O_info_t*) VOIDPTR(R_helper);
+  vars_protected++;
+  herr_t return_val = H5Oget_info(loc_id, oinfo);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  size_helper = guess_nelem(R_oinfo, h5_datatype[DT_H5O_info_t]);
+  R_oinfo = PROTECT(H5ToR_single_step(oinfo, h5_datatype[DT_H5O_info_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 2));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SET_VECTOR_ELT(__ret_list, 1, R_oinfo);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_STRING_ELT(__ret_list_names, 1, mkChar("oinfo"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
+/* H5_DLL herr_t H5Oget_info_by_idx(hid_t loc_id, const char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5O_info_t *oinfo, hid_t lapl_id); */
+SEXP R_H5Oget_info_by_idx(SEXP R_loc_id, SEXP R_group_name, SEXP R_idx_type, SEXP R_order, SEXP R_n, SEXP R_oinfo, SEXP R_lapl_id){
   hsize_t size_helper;
   SEXP R_helper = R_NilValue;
   int vars_protected=0;
@@ -302,7 +236,7 @@ SEXP R_H5Oget_info_by_idx1(SEXP R_loc_id, SEXP R_group_name, SEXP R_idx_type, SE
   H5O_info_t* oinfo= (H5O_info_t*) VOIDPTR(R_helper);
   vars_protected++;
   hid_t lapl_id = SEXP_to_longlong(R_lapl_id, 0);
-  herr_t return_val = H5Oget_info_by_idx1(loc_id, group_name, idx_type, order, n, oinfo, lapl_id);
+  herr_t return_val = H5Oget_info_by_idx(loc_id, group_name, idx_type, order, n, oinfo, lapl_id);
   SEXP R_return_val= R_NilValue;
   R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
   vars_protected++;
@@ -323,46 +257,8 @@ SEXP R_H5Oget_info_by_idx1(SEXP R_loc_id, SEXP R_group_name, SEXP R_idx_type, SE
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Oget_info_by_idx2(hid_t loc_id, const char *group_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n, H5O_info_t *oinfo, unsigned fields, hid_t lapl_id); */
-SEXP R_H5Oget_info_by_idx2(SEXP R_loc_id, SEXP R_group_name, SEXP R_idx_type, SEXP R_order, SEXP R_n, SEXP R_oinfo, SEXP R_fields, SEXP R_lapl_id){
-  hsize_t size_helper;
-  SEXP R_helper = R_NilValue;
-  int vars_protected=0;
-  R_oinfo = PROTECT(duplicate(R_oinfo));
-  vars_protected++;
-  hid_t loc_id = SEXP_to_longlong(R_loc_id, 0);
-  const char* group_name = CHAR(STRING_ELT(R_group_name, 0));
-  H5_index_t idx_type = SEXP_to_longlong(R_idx_type, 0);
-  H5_iter_order_t order = SEXP_to_longlong(R_order, 0);
-  hsize_t n = SEXP_to_longlong(R_n, 0);
-  R_helper = PROTECT(RToH5(R_oinfo, h5_datatype[DT_H5O_info_t], guess_nelem(R_oinfo, h5_datatype[DT_H5O_info_t])));
-  H5O_info_t* oinfo= (H5O_info_t*) VOIDPTR(R_helper);
-  vars_protected++;
-  unsigned fields = SEXP_to_longlong(R_fields, 0);
-  hid_t lapl_id = SEXP_to_longlong(R_lapl_id, 0);
-  herr_t return_val = H5Oget_info_by_idx2(loc_id, group_name, idx_type, order, n, oinfo, fields, lapl_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  size_helper = guess_nelem(R_oinfo, h5_datatype[DT_H5O_info_t]);
-  R_oinfo = PROTECT(H5ToR_single_step(oinfo, h5_datatype[DT_H5O_info_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 2));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SET_VECTOR_ELT(__ret_list, 1, R_oinfo);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_STRING_ELT(__ret_list_names, 1, mkChar("oinfo"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
-/* H5_DLL herr_t H5Oget_info_by_name1(hid_t loc_id, const char *name, H5O_info_t *oinfo, hid_t lapl_id); */
-SEXP R_H5Oget_info_by_name1(SEXP R_loc_id, SEXP R_name, SEXP R_oinfo, SEXP R_lapl_id){
+/* H5_DLL herr_t H5Oget_info_by_name(hid_t loc_id, const char *name, H5O_info_t *oinfo, hid_t lapl_id); */
+SEXP R_H5Oget_info_by_name(SEXP R_loc_id, SEXP R_name, SEXP R_oinfo, SEXP R_lapl_id){
   hsize_t size_helper;
   SEXP R_helper = R_NilValue;
   int vars_protected=0;
@@ -374,107 +270,7 @@ SEXP R_H5Oget_info_by_name1(SEXP R_loc_id, SEXP R_name, SEXP R_oinfo, SEXP R_lap
   H5O_info_t* oinfo= (H5O_info_t*) VOIDPTR(R_helper);
   vars_protected++;
   hid_t lapl_id = SEXP_to_longlong(R_lapl_id, 0);
-  herr_t return_val = H5Oget_info_by_name1(loc_id, name, oinfo, lapl_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  size_helper = guess_nelem(R_oinfo, h5_datatype[DT_H5O_info_t]);
-  R_oinfo = PROTECT(H5ToR_single_step(oinfo, h5_datatype[DT_H5O_info_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 2));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SET_VECTOR_ELT(__ret_list, 1, R_oinfo);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_STRING_ELT(__ret_list_names, 1, mkChar("oinfo"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
-/* H5_DLL herr_t H5Oget_info_by_name2(hid_t loc_id, const char *name, H5O_info_t *oinfo, unsigned fields, hid_t lapl_id); */
-SEXP R_H5Oget_info_by_name2(SEXP R_loc_id, SEXP R_name, SEXP R_oinfo, SEXP R_fields, SEXP R_lapl_id){
-  hsize_t size_helper;
-  SEXP R_helper = R_NilValue;
-  int vars_protected=0;
-  R_oinfo = PROTECT(duplicate(R_oinfo));
-  vars_protected++;
-  hid_t loc_id = SEXP_to_longlong(R_loc_id, 0);
-  const char* name = CHAR(STRING_ELT(R_name, 0));
-  R_helper = PROTECT(RToH5(R_oinfo, h5_datatype[DT_H5O_info_t], guess_nelem(R_oinfo, h5_datatype[DT_H5O_info_t])));
-  H5O_info_t* oinfo= (H5O_info_t*) VOIDPTR(R_helper);
-  vars_protected++;
-  unsigned fields = SEXP_to_longlong(R_fields, 0);
-  hid_t lapl_id = SEXP_to_longlong(R_lapl_id, 0);
-  herr_t return_val = H5Oget_info_by_name2(loc_id, name, oinfo, fields, lapl_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  size_helper = guess_nelem(R_oinfo, h5_datatype[DT_H5O_info_t]);
-  R_oinfo = PROTECT(H5ToR_single_step(oinfo, h5_datatype[DT_H5O_info_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 2));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SET_VECTOR_ELT(__ret_list, 1, R_oinfo);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_STRING_ELT(__ret_list_names, 1, mkChar("oinfo"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
-/* H5_DLL herr_t H5Oget_info1(hid_t loc_id, H5O_info_t *oinfo); */
-SEXP R_H5Oget_info1(SEXP R_loc_id, SEXP R_oinfo){
-  hsize_t size_helper;
-  SEXP R_helper = R_NilValue;
-  int vars_protected=0;
-  R_oinfo = PROTECT(duplicate(R_oinfo));
-  vars_protected++;
-  hid_t loc_id = SEXP_to_longlong(R_loc_id, 0);
-  R_helper = PROTECT(RToH5(R_oinfo, h5_datatype[DT_H5O_info_t], guess_nelem(R_oinfo, h5_datatype[DT_H5O_info_t])));
-  H5O_info_t* oinfo= (H5O_info_t*) VOIDPTR(R_helper);
-  vars_protected++;
-  herr_t return_val = H5Oget_info1(loc_id, oinfo);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  size_helper = guess_nelem(R_oinfo, h5_datatype[DT_H5O_info_t]);
-  R_oinfo = PROTECT(H5ToR_single_step(oinfo, h5_datatype[DT_H5O_info_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 2));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SET_VECTOR_ELT(__ret_list, 1, R_oinfo);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_STRING_ELT(__ret_list_names, 1, mkChar("oinfo"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
-/* H5_DLL herr_t H5Oget_info2(hid_t loc_id, H5O_info_t *oinfo, unsigned fields); */
-SEXP R_H5Oget_info2(SEXP R_loc_id, SEXP R_oinfo, SEXP R_fields){
-  hsize_t size_helper;
-  SEXP R_helper = R_NilValue;
-  int vars_protected=0;
-  R_oinfo = PROTECT(duplicate(R_oinfo));
-  vars_protected++;
-  hid_t loc_id = SEXP_to_longlong(R_loc_id, 0);
-  R_helper = PROTECT(RToH5(R_oinfo, h5_datatype[DT_H5O_info_t], guess_nelem(R_oinfo, h5_datatype[DT_H5O_info_t])));
-  H5O_info_t* oinfo= (H5O_info_t*) VOIDPTR(R_helper);
-  vars_protected++;
-  unsigned fields = SEXP_to_longlong(R_fields, 0);
-  herr_t return_val = H5Oget_info2(loc_id, oinfo, fields);
+  herr_t return_val = H5Oget_info_by_name(loc_id, name, oinfo, lapl_id);
   SEXP R_return_val= R_NilValue;
   R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
   vars_protected++;
@@ -607,26 +403,6 @@ SEXP R_H5Oopen_by_idx(SEXP R_loc_id, SEXP R_group_name, SEXP R_idx_type, SEXP R_
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Orefresh(hid_t oid); */
-SEXP R_H5Orefresh(SEXP R_oid){
-  int vars_protected=0;
-  hid_t oid = SEXP_to_longlong(R_oid, 0);
-  herr_t return_val = H5Orefresh(oid);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 1));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
 /* H5_DLL herr_t H5Oset_comment(hid_t obj_id, const char *comment); */
 SEXP R_H5Oset_comment(SEXP R_obj_id, SEXP R_comment){
   int vars_protected=0;
